@@ -1745,7 +1745,7 @@ pango_fc_font_map_list_families (PangoFontMap      *fontmap,
     *n_families = priv->n_families;
 
   if (families)
-    *families = g_memdup (priv->families, priv->n_families * sizeof (PangoFontFamily *));
+    *families = g_memdup2 (priv->families, priv->n_families * sizeof (PangoFontFamily *));
 }
 
 static PangoFontFamily *
@@ -1837,7 +1837,6 @@ pango_fc_make_pattern (const  PangoFontDescription *description,
   int slant;
   double weight;
   PangoGravity gravity;
-  FcBool vertical;
   char **families;
   int i;
   int width;
@@ -1848,7 +1847,6 @@ pango_fc_make_pattern (const  PangoFontDescription *description,
   width = pango_fc_convert_width_to_fc (pango_font_description_get_stretch (description));
 
   gravity = pango_font_description_get_gravity (description);
-  vertical = PANGO_GRAVITY_IS_VERTICAL (gravity) ? FcTrue : FcFalse;
 
   /* The reason for passing in FC_SIZE as well as FC_PIXEL_SIZE is
    * to work around a bug in libgnomeprint where it doesn't look
@@ -1857,13 +1855,14 @@ pango_fc_make_pattern (const  PangoFontDescription *description,
    * Putting FC_SIZE in here slightly reduces the efficiency
    * of caching of patterns and fonts when working with multiple different
    * dpi values.
+   *
+   * Do not pass FC_VERTICAL_LAYOUT true as HarfBuzz shaping assumes false.
    */
   pattern = FcPatternBuild (NULL,
 			    PANGO_FC_VERSION, FcTypeInteger, pango_version(),
 			    FC_WEIGHT, FcTypeDouble, weight,
 			    FC_SLANT,  FcTypeInteger, slant,
 			    FC_WIDTH,  FcTypeInteger, width,
-			    FC_VERTICAL_LAYOUT,  FcTypeBool, vertical,
 #ifdef FC_VARIABLE
 			    FC_VARIABLE,  FcTypeBool, FcDontCare,
 #endif
@@ -3263,7 +3262,7 @@ pango_fc_family_list_faces (PangoFontFamily  *family,
     *n_faces = fcfamily->n_faces;
 
   if (faces)
-    *faces = g_memdup (fcfamily->faces, fcfamily->n_faces * sizeof (PangoFontFace *));
+    *faces = g_memdup2 (fcfamily->faces, fcfamily->n_faces * sizeof (PangoFontFace *));
 }
 
 static PangoFontFace *
